PyXMake Developer Guide: PyXMake.VTL.bundle Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.bundle Namespace Reference

## Functions
| main (BuildID, files="*.*", source=os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist","pycodac"), output=os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist"), scratch=VTL.Scratch, verbosity=2, **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Create an installer from an application folder using NSIS
    Created on 11.05.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          - Requires PyCODAC in PYTHONPATH.

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.bundle.main | ( |  | BuildID,
|  |  | files = "*.*",
|  |  | source = os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist","pycodac"),
|  |  | output = os.path.join(__pyc_src_path,"Plugin","JupyterLab","src",".dist"),
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 43 of file bundle.py.